package com.ntut.csie.game;

import android.graphics.Color;
import android.graphics.Paint;
import android.view.KeyEvent;
import android.view.MotionEvent;

public class StateRun extends GameState {
	private Paint mPaint;
	
	private MovingBitmap mBackground;
	private MovingBitmap mBall;
	
	private Animation fan;
	private Audio mMyMusic;
	private Integer mScore;
	
	//private Map mMap1;
	
	private boolean grab;
	
	private MovingBitmap[] map;
	private int[] mapDistanseX;
	private int[] mapDistanseY;
	private int mouseX;
	private int mouseY;
	private int downX;
	private int downY;
	private int upX;
	private int upY;
	
	public StateRun(){
		mPaint = new Paint();
		mPaint.setColor(Color.GREEN);
		mPaint.setAntiAlias(true);
		
		mMyMusic = new Audio(R.raw.smb);
				
		mBackground = new MovingBitmap();
		mBackground.SetResource(R.drawable.game_run);
		
		mBall = new MovingBitmap();
		mBall.SetResource(R.drawable.ball_sticky);
		
		fan = new Animation();
		fan.AddFrame(R.drawable.fan01);
		fan.AddFrame(R.drawable.fan02);
		fan.AddFrame(R.drawable.fan03);
		fan.AddFrame(R.drawable.fan04);
		
		mScore = new Integer();
		mScore.SetXY(400, 5);
		mScore.SetInteger(100);
		
		//mMap1 = new Map();
		
		mapDistanseX = new int[9];
		mapDistanseY = new int[9];
		map = new MovingBitmap[9];
		
		for(int i = 0 ; i < 9 ; i++)
			map[i] = new MovingBitmap();
		
		map[0].SetResource(R.drawable.map01);
		map[1].SetResource(R.drawable.map02);
		map[2].SetResource(R.drawable.map03);
		map[3].SetResource(R.drawable.map04);
		map[4].SetResource(R.drawable.map05);
		map[5].SetResource(R.drawable.map06);
		map[6].SetResource(R.drawable.map07);
		map[7].SetResource(R.drawable.map08);
		map[8].SetResource(R.drawable.map09);
	}
	
	@Override
	public void Initialize() {
		super.Initialize();
		
		mBackground.SetXY(0, 0);
		mBall.SetXY(200, 200);
		fan.SetXY(300, 230);
		mMyMusic.Play();
		
		for(int i=0;i<9;i++){
			if( i == 0 || i == 3 || i ==6)
				mapDistanseX[i] = 0;
			else if( i == 1 || i == 4 || i ==7)
				mapDistanseX[i] = 480;
			else if( i == 2 || i == 5 || i ==8)
				mapDistanseX[i] = 960;
			
			if( i == 0 || i == 1 || i ==2)
				mapDistanseY[i] = 0;
			else if( i == 3 || i == 4 || i ==5)
				mapDistanseY[i] = 320;
			else  if( i == 6 || i == 7 || i ==8)
				mapDistanseY[i] = 640;
		}
		
		mouseX = mouseY = downX = upX = downY = upY = 0;
		
		for(int i = 0 ; i < 9 ;i++)
			map[i].SetXY(mapDistanseX[i], mapDistanseY[i]);
	}

	@Override
	public void OnShow() {
		mBackground.OnShow();
		
		for(int i = 0 ; i < 9 ;i++){
			if(map[i].GetX()>=0 || map[i].GetX()+map[i].GetWidth()<=480 || map[i].GetY()>=0 || map[i].GetY()+ map[i].GetHeight()<=320)
				map[i].OnShow();
		}
		
		//mMap1.OnShow();
		mBall.OnShow();
		fan.OnShow();
		mScore.OnShow();
	}

	@Override
	public void OnMove() {
		fan.SetXY(fan.GetX() - 1, fan.GetY());
		fan.OnMove();
		
		//mMap1.OnMove();
		
		if (mBall.GetX() <= 16 && mBall.GetY() <= 16)
		{
				mMyMusic.Stop();
				GameView.SetState(STATE_STOP);
		}
	}
	
public void OnTouchEvent(MotionEvent event) { 
        
        int X = (int)event.getX();
        int Y = (int)event.getY();
  
        switch (event.getAction()) {   
  
        case MotionEvent.ACTION_DOWN:
                int centerX = mBall.GetX() + 16;  
                int centerY = mBall.GetY() + 16;
                downX = X;
                downY = Y;
                
                grab = false;
                  
                double radCircle  = Math.sqrt( (double) (((centerX-X)*(centerX-X)) + (centerY-Y)*(centerY-Y)));  

                if (radCircle < 16){
                	grab = true;
                    break;
                } 
             break;
             
        case MotionEvent.ACTION_MOVE:
        	if (grab) {
        		mBall.SetXY(X - 16, Y - 16);
        	}
        	upX = X;
        	upY = Y;
        	
        	mouseX = upX - downX;
        	mouseY = upY - downY;
        	if(!grab){
	        	for(int i = 0 ; i < 9 ;i++){
		        		mapDistanseX[i] += mouseX;
		        		mapDistanseY[i] += mouseY;
		        		map[i].SetXY(mapDistanseX[i], mapDistanseY[i]);
        		}
        	}
        	
        	downX = upX;
        	downY = upY;
            break;   
  
        case MotionEvent.ACTION_UP:   
            grab = false;
            break;
        }
        
    }

	@Override
	public void Pause() {
		super.Pause();
		mMyMusic.Pause();
	}

	@Override
	public void Unpause() {
		super.Unpause();
		mMyMusic.Resume();
	}
	
	@Override
	public void Destroy() {
		if(!mMyMusic.IsNull()) {
			mMyMusic.Stop();
		}
	}
}
