package com.ntut.csie.game;

import com.ntut.csie.game.GameView.GameThread;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.util.Log;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.Window;
import android.widget.Button;

public class Game extends Activity implements View.OnClickListener {
    
	private static final int MENU_MENU = 0;
    private static final int MENU_PAUSE = 1;
    private static final int MENU_RESUME = 2;
    private static final int MENU_EXIT = 3;
    
	/** A handle to the thread that's actually running the animation. */
    private GameThread mGameThread;
    /** A handle to the View in which the game is running. */
    private GameView mGameView;
    
    private SensorManager mSensorManager;
    
    private Button mStartButton;
    private Button mHelpButton;
    private Button mAboutButton;
    private Button mExitButton;
    private Button mMenuButton;
	
	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        mSensorManager = (SensorManager) getSystemService(SENSOR_SERVICE);
        setContentView(R.layout.main);
        
        mStartButton = (Button)findViewById(R.id.Button01);
        mStartButton.setOnClickListener(this);
        
        mHelpButton = (Button)findViewById(R.id.Button02);
        mHelpButton.setOnClickListener(this);
        
        mAboutButton = (Button)findViewById(R.id.Button03);
        mAboutButton.setOnClickListener(this);
        
        mExitButton = (Button)findViewById(R.id.Button04);
        mExitButton.setOnClickListener(this);

        mMenuButton = (Button)findViewById(R.id.Button05);
        mMenuButton.setOnClickListener(this);
        
        mGameView = (GameView)findViewById(R.id.GameView);
        mGameThread = mGameView.getThread();
        
        mGameView.SetStartButton(mStartButton);
        mGameView.SetHelpButton(mHelpButton);
        mGameView.SetAboutButton(mAboutButton);
        mGameView.SetExitButton(mExitButton);
        mGameView.SetMenuButton(mMenuButton);

    }
    
    @Override
    protected void onPause() {
    	mGameThread.pause();
    	super.onPause();
    }
    
    @Override
    protected void onResume() {
    	mSensorManager.registerListener(mGameView,
                SensorManager.SENSOR_ORIENTATION,
                SensorManager.SENSOR_DELAY_GAME);
    	mGameThread.unpause();
    	super.onResume();
    }
    
    @Override
    protected void onStop() {
    	mSensorManager.unregisterListener(mGameView);
    	super.onStop();
    }
    
    @Override
    protected void onDestroy(){
    	mGameThread.destory();
    	super.onDestroy();
    }
    
    /*To control the attributes of Buttons, TextViews, ...*/
    public void onClick(View v) {
        // this is the first screen
        if (mStartButton.equals(v)) {
            mStartButton.setVisibility(View.INVISIBLE);
            mHelpButton.setVisibility(View.INVISIBLE);
            mAboutButton.setVisibility(View.INVISIBLE);
            mExitButton.setVisibility(View.INVISIBLE);
            mGameThread.setGameState(GameView.STATE_RUNNING);
        }
        // open a Help AlertDialog to display the instructions
        else if (mHelpButton.equals(v)) {
        	AlertDialog dialog = new AlertDialog.Builder(Game.this).create();
            //dialog.setTitle("HELP");
            dialog.setMessage("Your instructions here :)");
            dialog.setButton("OK", new DialogInterface.OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                	dialog.cancel();
                }
            });
            dialog.show();
        }
        // open a About AlertDialog
        else if (mAboutButton.equals(v)) {
        	AlertDialog dialog = new AlertDialog.Builder(Game.this).create();
            dialog.setTitle("ABOUT");
            dialog.setMessage("About your game here.");
            dialog.setButton("OK", new DialogInterface.OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                	dialog.cancel();
                }
            });
            // use your icon displayed on the topLeft
            dialog.setIcon(R.drawable.icon);
            dialog.show();
        }
        // to close the activity
        else if (mExitButton.equals(v)) {
            finish();
        }
     // this is a return-to-menu button
        else if (mMenuButton.equals(v)) {
            mMenuButton.setVisibility(View.INVISIBLE);
            mStartButton.setVisibility(View.VISIBLE);
            mHelpButton.setVisibility(View.VISIBLE);
            mAboutButton.setVisibility(View.VISIBLE);
            mExitButton.setVisibility(View.VISIBLE);
            mGameThread.setGameState(GameView.STATE_READY);
        }
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        super.onCreateOptionsMenu(menu);

        menu.add(0, MENU_MENU, 0, "Menu");
        menu.add(0, MENU_PAUSE, 0, "Pause");
        menu.add(0, MENU_RESUME, 0, "Resume");
        menu.add(0, MENU_EXIT, 0, "Exit");

        return true;
    }
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
        	case MENU_MENU:
        		mMenuButton.setVisibility(View.INVISIBLE);
                mStartButton.setVisibility(View.VISIBLE);
                mHelpButton.setVisibility(View.VISIBLE);
                mAboutButton.setVisibility(View.VISIBLE);
                mExitButton.setVisibility(View.VISIBLE);
        		mGameThread.setGameState(GameView.STATE_READY);
        		return true;
        	case MENU_PAUSE:
            	mGameThread.pause();
                return true;
            case MENU_RESUME:
                mGameThread.unpause();
                return true;
            case MENU_EXIT:
                finish();
                return true;
        }

        return false;
    }
    
    @Override
    public boolean onKeyDown(int keyCode, KeyEvent msg) {
        if (keyCode == KeyEvent.KEYCODE_BACK || keyCode == KeyEvent.KEYCODE_MENU) {
            return super.onKeyDown(keyCode, msg);
        } else {
        	mGameThread.KeyDown(keyCode);
            return true;
        }
    }
    
    @Override
    public boolean onKeyUp(int keyCode, KeyEvent msg) {
        if (keyCode == KeyEvent.KEYCODE_BACK || keyCode == KeyEvent.KEYCODE_MENU) {
            return super.onKeyUp(keyCode, msg);
        } else {
        	mGameThread.KeyUp(keyCode);
            return true;
        }
    }
}