package com.ntut.csie.game.extend;

import com.ntut.csie.game.core.MovingBitmap;

import java.util.ArrayList;

public class Animation {
	private int mX;
	private int mY;
	private int mAniIndex = 0;
	private int mDelayCount;
	private int mDelayCounter;
	private boolean mIsOneShot = false;
	private ArrayList<MovingBitmap> mAnimation = new ArrayList<MovingBitmap>();
	
	public Animation() {}
	
	public Animation(int count) {
		SetDelay(count);
	}
	
	public void AddFrame(MovingBitmap bitmap) {
		mAnimation.add(bitmap);
	}
	
	public void AddFrame(int resId) {
		mAnimation.add(new MovingBitmap(resId));
	}
	
	public void AddFrame(String fileName) {
		mAnimation.add(new MovingBitmap(fileName));
	}
	
	public void SetXY(int x, int y) {
		mX = x;
		mY = y;
	}
	
	public void SetDelay(int count) {
		mDelayCount = count;
		mDelayCounter = mDelayCount;
	}
	
	public void OnMove() {
		if(--mDelayCounter <= 0) {
			mDelayCounter = mDelayCount;
			if(!IsLastFrame() && mAniIndex >= 0)	// means that animation is playing
				mAniIndex ++;
			else if(mIsOneShot)
				mAniIndex = -1;						// stop the animation
			else
				Reset();
		}
	}
	
	public void OnShow() {
		if(mAniIndex >= 0) {
			mAnimation.get(mAniIndex).SetXY(mX, mY);
			mAnimation.get(mAniIndex).OnShow();
		}
	}
	
	public boolean IsLastFrame() {
		return mAniIndex == mAnimation.size() - 1;
	}
	
	public void Reset() {
		mAniIndex = 0;
	}
	
	public int Size() {
		return mAnimation.size();
	}
	
	/* the animation plays only once */
	public void SetOneShot(boolean oneShot) {
		mIsOneShot = oneShot;
	}
	
	public void SetFrame(int index) {
		if(index < mAnimation.size() - 1 && mAniIndex >= 0)
			mAniIndex = index;
	}
	
	public int GetCurrentFrameIndex() {
		return mAniIndex;
	}
	
	public int GetSize() {
		return mAnimation.size();
	}
	
	public int GetY() {
		return mY;
	}
	
	public int GetX() {
		return mX;
	}
	
	public int GetWidth() {
		return mAnimation.get(mAniIndex).GetWidth();
	}
	
	public int GetHeight() {
		return mAnimation.get(mAniIndex).GetHeight();
	}
	
	public void Release() {
		for(int i = mAnimation.size() - 1; i >= 0; i--) {
			mAnimation.get(i).Release();
			mAnimation.remove(i);
		}
		mAnimation = null;
	}
}
