package com.ntut.csie.game.gameState;

import com.ntut.csie.game.GameView;

public abstract class GameState {
	public static final int STATE_READY = GameView.STATE_READY;
    public static final int STATE_RUNNING = GameView.STATE_RUNNING;
    public static final int STATE_STOP = GameView.STATE_STOP;
    public static final int KEY_UP = GameView.KEY_UP;
    public static final int KEY_DOWN = GameView.KEY_DOWN;
    public static final int KEY_LEFT = GameView.KEY_LEFT;
    public static final int KEY_RIGHT = GameView.KEY_RIGHT;
    public static final int KEY_SELECT = GameView.KEY_SELECT;
    public static final int Width = GameView.Width;
    public static final int Height = GameView.Height;
    public static final int STAGE_NUMBER = 2;
    public static int mStageIndex;	// now playing stage
	protected boolean isPaused = false;
    
    protected boolean isMovingUp;
    protected boolean isMovingDown;
    protected boolean isMovingLeft;
    protected boolean isMovingRight;
    protected boolean isSelecting;
	
	public abstract void OnMove();
	
	public void Initialize() {
		isMovingUp = false;
        isMovingDown = false;
        isMovingLeft = false;
        isMovingRight = false;
	}
	
	public void OnShow() {}
	
	public abstract void Destroy();
	
	public void Pause() {
		isPaused = true;
	}
	
	public void Unpause() {
		isPaused = false;
	}
		
	public boolean IsPaused() {
		return isPaused;
	}
	
	public void GoToState(int mode) {
		GameView.SetState(mode);
	}
	
	// touch event handler
	public void OnTouchDown(int x, int y) {}
	public void OnTouchMove(int x, int y) {}
	public void OnTouchUp(int x, int y) {}
	
	// device rotate event handler
	public void OnDeviceAzimuth(float degrees) {}
	public void OnDevicePitch(float degrees) {}
	public void OnDeviceRoll(float degrees) {}
	
	// device accelerate event handler
	public void OnDeviceAccelerateX(float force) {}
	public void OnDeviceAccelerateY(float force) {}
	public void OnDeviceAccelerateZ(float force) {}
	
	// key event handler
	public void KeyDown(int keyCode) {
		if(keyCode == KEY_UP) {
            isMovingUp = true;
        }
        if(keyCode == KEY_DOWN) {
            isMovingDown = true;
        }
        if(keyCode == KEY_LEFT) {
            isMovingLeft = true;
        }
        if(keyCode == KEY_RIGHT) {
            isMovingRight = true;
        }
        if(keyCode == KEY_SELECT) {
            isSelecting = true;
        }
	}
	
	public void KeyUp(int keyCode) {
		if(keyCode == KEY_UP) {
            isMovingUp = false;
        }
        if(keyCode == KEY_DOWN) {
            isMovingDown = false;
        }
        if(keyCode == KEY_LEFT) {
            isMovingLeft = false;
        }
        if(keyCode == KEY_RIGHT) {
            isMovingRight = false;
        }
        if(keyCode == KEY_SELECT) {
            isSelecting = false;
        }
	}
}
