package com.ntut.csie.game.gameState;

import com.ntut.csie.game.R;
import com.ntut.csie.game.core.Audio;
import com.ntut.csie.game.core.MovingBitmap;
import com.ntut.csie.game.core.SoundEffects;
import com.ntut.csie.game.extend.Animation;
import com.ntut.csie.game.extend.Integer;

public class StateRun extends GameState {
	private SoundEffects mSoundEffects;
	
	private MovingBitmap mBackground;
	private MovingBitmap mBall;
	private MovingBitmap mBall2;
	private MovingBitmap mBall3;
	private MovingBitmap mMessage;
	
	private Animation fan;
	private Audio mMyMusic;
	private Integer mScore;
	
	private long lastTime;
	private boolean grab;
	private boolean visible = true;
	
	private final int mSoundId = 1;
	
	public StateRun(){		
		mSoundEffects = new SoundEffects();
//		mSoundEffects.SetResource(mSoundId, R.raw.shoot);
		mSoundEffects.SetResource(mSoundId, "shoot.wav");
		
		mMyMusic = new Audio();
//		mMyMusic.SetResource(R.raw.my_music);
		mMyMusic.SetResource("my_music.mid");
		
		mBackground = new MovingBitmap();
		mBackground.SetResource(R.drawable.game_run);
//		mBackground.SetResource("game_run.png");
		
		mBall = new MovingBitmap();
		mBall.SetResource(R.drawable.ball_sticky);
		
		mBall2 = new MovingBitmap();
		mBall2.SetResource(R.drawable.ball_sticky);
		mBall2.Resize(32, 64);
		
		mBall3 = new MovingBitmap();
		mBall3.SetResource(R.drawable.ball_red);
		
		fan = new Animation();
		fan.AddFrame(R.drawable.fan01);
		fan.AddFrame(R.drawable.fan02);
		fan.AddFrame(R.drawable.fan03);
		fan.AddFrame(R.drawable.fan04);
		
		mMessage = new MovingBitmap();
		mMessage.SetResource(R.drawable.message);
		
		mScore = new Integer();
		mScore.SetXY(675, 5);
		mScore.SetInteger(168);
	}
	
	@Override
	public void Initialize() {
		super.Initialize();
		mMyMusic.Play();
		
//		mBackground.SetXY(0, 0);
		mBall.SetXY(120, 120);
		mBall2.SetXY(5, 5);
		mBall3.SetXY(350, 300);
		mMessage.SetXY(190, 90);
		fan.SetXY(300, 250);
		
		lastTime = System.currentTimeMillis();
	}

	@Override
	public void OnShow() {
		mBackground.OnShow();
		mBall2.OnShow();
		mBall.OnShow();
		fan.OnShow();
		mBall3.OnShow();
		mScore.OnShow();
		if(visible)
			mMessage.OnShow();
		
		super.OnShow();
	}

	@Override
	public void OnMove() {
		if(System.currentTimeMillis() - lastTime > 3000) {
			visible = false;
			mSoundEffects.Play(mSoundId);
			lastTime = System.currentTimeMillis();
		}
		
		if(fan.GetX() <= 0) {
			fan.SetXY(300, 180);
		} else {
			fan.SetXY(fan.GetX() - 1, fan.GetY());
			fan.OnMove();
		}
		
		if (mBall.GetX() <= mBall.GetWidth()/2 && mBall.GetY() <= mBall.GetHeight()/2) {
			mMyMusic.Stop();
			GoToState(STATE_STOP);
		}
		
		if(isMovingRight) 
			mBall3.SetXY(mBall3.GetX() + 1, mBall3.GetY());
		else if(isMovingLeft)
			mBall3.SetXY(mBall3.GetX() - 1, mBall3.GetY());
		else if(isMovingUp)
			mBall3.SetXY(mBall3.GetX(), mBall3.GetY() - 1);
		else if(isMovingDown)
			mBall3.SetXY(mBall3.GetX(), mBall3.GetY() + 1);
	}
	
	@Override
	public void OnTouchDown(int x, int y) {
		super.OnTouchDown(x, y);
		
		int centerX = mBall.GetX() + 16;  
        int centerY = mBall.GetY() + 16;
        
        grab = false;
        
        // calculate the radius from the touch to the center of the ball  
        double radCircle  = Math.sqrt( (double) (((centerX-x)*(centerX-x)) + (centerY-y)*(centerY-y)));  
          
        // if the radius is smaller then 23 (radius of a ball is 22), then it must be on the ball  
        if (radCircle < mBall.GetWidth()/2)
        	grab = true;
	}
	
	@Override
	public void OnTouchMove(int x, int y) {
		if (grab) {
    		mBall.SetXY(x - mBall.GetWidth()/2, y - mBall.GetHeight()/2);
    	}
	}
	
	@Override
	public void OnTouchUp(int x, int y) {
		grab = false;
	}
	
	@Override
	public void OnDeviceRoll(float degrees) {
		int bx = mBall3.GetX();
		int by = mBall3.GetY();
		if(Math.abs(degrees) > 5.0f && bx >= 0 && bx <= 480) {
			if(degrees > 0.0f)
				bx -= 1;
			else
				bx += 1;
			mBall3.SetXY(bx, by);
		}
	}
	
	@Override
	public void KeyDown(int keyCode) {
		super.KeyDown(keyCode);
	}
	
	@Override
	public void KeyUp(int keyCode) {
		super.KeyUp(keyCode);
	}

	@Override
	public void Pause() {
		super.Pause();
		mMyMusic.Pause();
	}

	@Override
	public void Unpause() {
		super.Unpause();
		mMyMusic.Resume();
	}
	
	@Override
	public void Destroy() {
		mSoundEffects.Release();
		
		mMyMusic.Release();
		mBackground.Release();
		
		mBall.Release();
		mBall2.Release();
		fan.Release();
	}
}
